@@ -33,6 +33,7 @@ from backend.remote.piston_remoter import PistonRemoter
 from shutil import copytree, ignore_patterns, rmtree
 DB_PATH = os.path.join(UBUNTUKYLIN_DATA_PATH,"uksc.db")
 XAPIAN_DB_SOURCE_PATH = os.path.join(UBUNTUKYLIN_DATA_PATH,"xapiandb")
+from models.globals import Globals
 #DB_PATH = "../data/uksc.db"
 
 QUERY_CATEGORY = "select * from category where name='%s'"
@@ -49,6 +50,8 @@ UPDATE_EXISTS = "update xp set exists_valid='%d' where id='%d'"
 
 import threading
 lock = threading.Lock()
+# from multiprocessing import Process,Lock
+# lock = Lock()
 
 class Database:
 
@@ -60,7 +63,8 @@ class Database:
         # no cache file, copy
         if not os.path.exists(destFile):
             if not os.path.exists(srcFile):
-                print("error with db file")
+                if (Globals.DEBUG_SWITCH):
+                    print("error with db file")
                 return
             open(destFile, "wb").write(open(srcFile, "rb").read())
 
@@ -83,21 +87,28 @@ class Database:
         # no cache file, copy
         if not os.path.exists(xapian_destFile):
             if not os.path.exists(xapian_srcFile):
-                print("No xapiandb source in /usr/share/ubuntu-kylin-software-center/data/,please reinstall it")
+                if (Globals.DEBUG_SWITCH):
+                    print("No xapiandb source in /usr/share/ubuntu-kylin-software-center/data/,please reinstall it")
                 return
             copytree(xapian_srcFile,xapian_destFile)
-            print("Xapiandb has been copy to cache")
+            if (Globals.DEBUG_SWITCH):
+                print("Xapiandb has been copy to cache")
 
         # cache xapiandb need update, copy
         if self.is_xapiancachedb_need_update():
             rmtree(xapian_destFile)
             copytree(xapian_srcFile,xapian_destFile)
-            print("cache xapiandb versin updated")
+            if (Globals.DEBUG_SWITCH):
+                print("cache xapiandb versin updated")
 
 
     def query_categories(self):
-        self.cursor.execute("select * from category")
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("select * from category")
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
 #        print "query_categories:",len(res),res
         return res
 
@@ -105,16 +116,23 @@ class Database:
         al = ''
 
         sql = "select id from category where name='%s'"
-
-        self.cursor.execute(sql % cate_name)
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute(sql % cate_name)
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         cateid = ''
         for i in res:
             cateid = i[0]
 
         sql = "select id,categories from application"
-        self.cursor.execute(sql)
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute(sql)
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         for i in res:
             aid = i[0]
             cstring = i[1]
@@ -130,10 +148,13 @@ class Database:
                     al += ','
 
         al = al[:-1]
-
         sql = "select app_name,display_name_cn from application where id in (%s) order by rating_total DESC"
-        self.cursor.execute(sql % al)
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute(sql % al)
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
 
         # for a in res:
         #     print a[0],"    ",a[1]
@@ -142,8 +163,13 @@ class Database:
 
     #return as (display_name, summary, description, rating_average,rating_total,review_total,download_total)
     def query_application(self,pkgname):
-        self.cursor.execute(QUERY_APP % (pkgname))
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute(QUERY_APP % (pkgname))
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
+
 #        print "query_application:",pkgname,len(res),res
         if len(res)==0:
             return []
@@ -152,8 +178,12 @@ class Database:
 
     #return as (display_name, app_name)
     def query_applications(self):
-        self.cursor.execute(QUERY_APPS)
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute(QUERY_APPS)
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
 #        print "query_application:",pkgname,len(res),res
         if len(res)==0:
             return []
@@ -161,7 +191,8 @@ class Database:
             return res
 
     def update_app_rnr(self,pkgname,rating_average,rating_total,review_total,download_total=0):
-        print(("update_app_rnr:",self.updatecount,pkgname,rating_average,rating_total,review_total,download_total))
+        if (Globals.DEBUG_SWITCH):
+            print(("update_app_rnr:",self.updatecount,pkgname,rating_average,rating_total,review_total,download_total))
         try:
             lock.acquire(True)
             self.cursor.execute(UPDATE_APP_RNR % (rating_average,rating_total,review_total,download_total,pkgname))
@@ -185,8 +216,12 @@ class Database:
         connectsrc = sqlite3.connect(srcFile, check_same_thread=False)
         cursorsrc = connectsrc.cursor()
 
-        self.cursor.execute("select count(*) from sqlite_master where type='table' and name='dict'")
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("select count(*) from sqlite_master where type='table' and name='dict'")
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         dictcount = ''
         for item in res:
             dictcount = item[0]
@@ -194,14 +229,22 @@ class Database:
         if(dictcount == 0):
             return True
 
-        self.cursor.execute("select value from dict where key='dbversion'")
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("select value from dict where key='dbversion'")
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         olddbversion = ''
         for item in res:
             olddbversion = int(item[0])
 
-        cursorsrc.execute("select value from dict where key='dbversion'")
-        res = cursorsrc.fetchall()
+        try:
+            lock.acquire(True)
+            cursorsrc.execute("select value from dict where key='dbversion'")
+            res = cursorsrc.fetchall()
+        finally:
+            lock.release()
         newdbversion = ''
         for item in res:
             newdbversion = int(item[0])
@@ -235,6 +278,7 @@ class Database:
                     for old_item in old_matches:
                         old_doc = old_item.document
                         old_version = old_doc.get_value(1) #valueslot:1 xapiandb version
+            #if (Globals.DEBUG_SWITCH):
             print(("old xapiandb  version:",old_version," new xapiandb version:",new_version))
         except:
             return True
@@ -246,23 +290,37 @@ class Database:
 
 
     def get_pagecount_by_pkgname(self, package_name):
-        self.cursor.execute("select review_total from application where app_name=?", (package_name,))
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("select review_total from application where app_name=?", (package_name,))
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         for item in res:
             review_total = item[0]
+            if(review_total == None):
+                review_total = 0
             return review_total / 10 + 1
 
     def get_review_by_pkgname(self, package_name, page):
         # get application id
-        self.cursor.execute("select id from application where app_name=?", (package_name,))
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("select id from application where app_name=?", (package_name,))
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         aid = ''
         for item in res:
             aid = str(item[0])
 
         # get review count
-        self.cursor.execute("select count(*) from review where aid_id=?", (aid,))
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("select count(*) from review where aid_id=?", (aid,))
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         count = ''
         for item in res:
             count = item[0]
@@ -299,8 +357,12 @@ class Database:
             # normal init, check and download newest reviews
             else:
                 # get newest review's id from local cache
-                self.cursor.execute("select id from review where aid_id=? order by date DESC limit 0,1", (aid,))
-                res = self.cursor.fetchall()
+                try:
+                    lock.acquire(True)
+                    self.cursor.execute("select id from review where aid_id=? order by date DESC limit 0,1", (aid,))
+                    res = self.cursor.fetchall()
+                finally:
+                    lock.release()
                 id = ''
                 for item in res:
                     id = item[0]
@@ -398,8 +460,12 @@ class Database:
 
         # all download check over, return reviews to show
         limit = (page - 1) * 10
-        self.cursor.execute("select id, aid_id, content, user_display, date, language, up_total, down_total from review where aid_id=? order by date DESC limit ?,10", (aid,limit))
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("select id, aid_id, content, user_display, date, language, up_total, down_total from review where aid_id=? order by date DESC limit ?,10", (aid,limit))
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         reviews = []
         for item in res:
             review = Review(package_name)
@@ -416,8 +482,12 @@ class Database:
         return reviews
 
     def get_pointout_is_show(self):
-        self.cursor.execute("select value from dict where key=?", ('pointout',))
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("select value from dict where key=?", ('pointout',))
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         for item in res:
             isshow = item[0]
             return isshow
@@ -436,8 +506,12 @@ class Database:
             lock.release()
 
     def get_pointout_apps(self):
-        self.cursor.execute("select app_name,rank_pointout from rank,application where rank_pointout!=0 and rank.aid_id=application.id order by rank_pointout")
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("select app_name,rank_pointout from rank,application where rank_pointout!=0 and rank.aid_id=application.id order by rank_pointout")
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         pointouts = []
         for item in res:
             app_name = item[0]
@@ -456,6 +530,9 @@ class Database:
         #    rank_recommend = item[1]
         #    recommends.append((app_name, rank_recommend))
         recommends.append(("youker-assistant","1"))
+        recommends.append(("com.tencent.mobileqq","1"))
+        recommends.append(("com.qqgame.hlddz","1"))
+        recommends.append(("cn.kuwo.player","1"))
         recommends.append(("atom","3"))
         recommends.append(("google-chrome-stable","3"))
         recommends.append(("sogoupinyin","1"))
@@ -472,7 +549,7 @@ class Database:
         recommends.append(("wireshark","9"))
         recommends.append(("librecad","12"))
         recommends.append(("flashplugin-installer","13"))
-        recommends.append(("brasero","13"))
+        # recommends.append(("brasero","13"))
         recommends.append(("uget","5"))
         recommends.append(("calibre","10"))
         recommends.append(("gimp","3"))
@@ -543,32 +620,32 @@ class Database:
         recommends.append(("gparted","14"))
         return recommends
 
-    def get_ratingrank_apps(self):
-        #self.cursor.execute("select app_name,rank_rating from rank,application where rank_rating!=0 and rank.aid_id=application.id order by rank_rating")
-        #res = self.cursor.fetchall()
-        #ratingranks = []
-        #for item in res:
-        #    app_name = item[0]
-        #    rank_rating = item[1]
-        #    ratingranks.append((app_name, rank_rating))
-        #return ratingranks
-        recommends = []
-        #recommends.append(("youker-assistant","1"))
-        recommends.append(("vlc","2"))
-        recommends.append(("synaptic","3"))
-        recommends.append(("gparted","3"))
-        recommends.append(("fcitx","3"))
-        recommends.append(("qtcreator","3"))
-        recommends.append(("rar","3"))
-        recommends.append(("shotwell","3"))
-        recommends.append(("stellarium","3"))
-        recommends.append(("ubuntu-restricted-extras","3"))
-        recommends.append(("stardict","3"))
-        recommends.append(("vim","14"))
-        recommends.append(("kylin-video","12"))
-        recommends.append(("gnome-screenshot","12"))
-        recommends.append(("empire","12"))
-        return recommends
+    # def get_ratingrank_apps(self):
+    #     #self.cursor.execute("select app_name,rank_rating from rank,application where rank_rating!=0 and rank.aid_id=application.id order by rank_rating")
+    #     #res = self.cursor.fetchall()
+    #     #ratingranks = []
+    #     #for item in res:
+    #     #    app_name = item[0]
+    #     #    rank_rating = item[1]
+    #     #    ratingranks.append((app_name, rank_rating))
+    #     #return ratingranks
+    #     recommends = []
+    #     #recommends.append(("youker-assistant","1"))
+    #     recommends.append(("vlc","2"))
+    #     recommends.append(("synaptic","3"))
+    #     recommends.append(("gparted","3"))
+    #     recommends.append(("fcitx","3"))
+    #     recommends.append(("qtcreator","3"))
+    #     recommends.append(("rar","3"))
+    #     recommends.append(("shotwell","3"))
+    #     recommends.append(("stellarium","3"))
+    #     recommends.append(("ubuntu-restricted-extras","3"))
+    #     recommends.append(("stardict","3"))
+    #     recommends.append(("vim","14"))
+    #     recommends.append(("kylin-video","12"))
+    #     recommends.append(("gnome-screenshot","12"))
+    #     recommends.append(("empire","12"))
+    #     return recommends
 
 
     def update_app_ratingavg(self, app_name, ratingavg, ratingtotal):
@@ -581,8 +658,12 @@ class Database:
 
     #------------add by kobe for windows replace------------
     def search_name_and_categories_record(self):
-        self.cursor.execute(QUERY_NAME_CATEGORIES)
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute(QUERY_NAME_CATEGORIES)
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         if len(res) == 0:
             return []
         else:
@@ -590,8 +671,12 @@ class Database:
 
     #------------add by kobe for windows replace------------
     def search_app_display_info(self, categories):
-        self.cursor.execute(QUERY_APP_ACCORD_CATEGORIES % (categories))
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute(QUERY_APP_ACCORD_CATEGORIES % (categories))
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         if len(res) == 0:
             return []
         else:
@@ -607,8 +692,12 @@ class Database:
             lock.release()
 
     def need_do_sourcelist_update(self):
-        self.cursor.execute("select value from dict where key=?", ('sourcelist_need_update',))
-        res = self.cursor.fetchall()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("select value from dict where key=?", ('sourcelist_need_update',))
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
         for item in res:
             re = item[0]
             return re
@@ -621,10 +710,26 @@ class Database:
         finally:
             lock.release()
 
+
+    #-------------kydroid APK ----------------
+    def query_apk_applications(self):
+        try:
+            lock.acquire(True)
+            self.cursor.execute("select app_name,display_name_cn,summary,description,rating_avg,rating_total,review_total from application where id > 3410 and categories = '17'")
+            res = self.cursor.fetchall()
+        finally:
+            lock.release()
+#        print "query_application:",pkgname,len(res),res
+        if len(res)==0:
+            return []
+        else:
+            return res
+
 if __name__ == "__main__":
     db = Database()
 
     # print db.get_pagecount_by_pkgname('gimp')
+    #if (Globals.DEBUG_SWITCH):
     print((db.is_cachedb_need_update()))
 
     # res = db.get_review_by_pkgname('gedit',2)
