@@ -24,6 +24,7 @@
 
 
 import os
+import pwd
 
 from xdg import BaseDirectory as xdg
 from PyQt5.QtCore import *
@@ -31,14 +32,22 @@ from PyQt5.QtGui import *
 from PyQt5.QtWidgets import *
 from backend.ubuntu_sw import safe_makedirs
 from models.application import Application
+from models.baseinfo import BaseInfo
 
 #########################################################
 
 UBUNTUKYLIN_SERVICE_PATH = "com.ubuntukylin.softwarecenter"
 UBUNTUKYLIN_INTERFACE_PATH = "com.ubuntukylin.softwarecenter"
 
-#UBUNTUKYLIN_SERVER = "http://192.168.70.129/uksc/"
-UBUNTUKYLIN_SERVER = "http://service.ubuntukylin.com:8001/uksc/"
+UBUNTUKYLIN_SERVER = "http://192.168.70.129:8001/uksc/"
+#UBUNTUKYLIN_SERVER = "http://service.ubuntukylin.com:8001/uksc/"
+
+#KYDROID_SOURCE_SERVER = "ftp://192.168.78.231/kydroid/"
+#KYDROID_SOURCE_SERVER = "http://ports.kylin.com/kylin/kydroid/"
+KYDROID_SOURCE_SERVER = "http://archive.kylinos.cn/kylin/kydroid/"
+#KYDROID_DOWNLOAD_PATH = "/var/lib/kydroid/kydroid2-1000-kylin/data/local/tmp"
+KYDROID_DOWNLOAD_PATH = "/var/lib/kydroid/kydroid2-" + str(os.getuid()) + "-" + str(pwd.getpwuid(os.getuid())[0]) + "/data/local/tmp"
+KYDROID_STARTAPP_ENV = "/usr/bin/startapp start_kydroid"
 
 Specials = ["\"%c\"", "%f","%F","%u","%U","%d","%D","%n","%N","%i","%c","%k","%v","%m","%M", "-caption", "/bin/sh", "sh", "-c", "STARTED_FROM_MENU=yes"]
 
@@ -103,7 +112,9 @@ class PageStates:
      SEARCHWINPAGE,
      SEARCHUAPAGE,
      SEARCHTRANSPAGE,
-     ) = list(range(14))
+     APKPAGE,
+     SEARCHAPKPAGE,
+     ) = list(range(16))
 
 # transaction types
 class TransactionTypes:
@@ -138,7 +149,7 @@ UBUNTUKYLIN_RES_ICON_PATH = UBUNTUKYLIN_DATA_PATH + "icons/"
 UBUNTUKYLIN_RES_AD_PATH = UBUNTUKYLIN_DATA_PATH + "ads/"
 UBUNTUKYLIN_RES_WIN_PATH = UBUNTUKYLIN_DATA_PATH + "winicons/"
 
-ITEM_LABEL_STYLE = ("QLabel{background-image:url(%s)}")
+ITEM_LABEL_STYLE = ("QLabel{background-image:url(%s);background-color:transparent;}")
 RECOMMEND_BUTTON_BK_STYLE = ("QPushButton{background-image:url(%s);border:0px;color:#497FAB;}")
 RECOMMEND_BUTTON_STYLE = ("QPushButton{border:0px;color:white;font-size:14px;background-image:url(%s)}QPushButton:hover{background-image:url(%s)}QPushButton:pressed{background-image:url(%s)}")
 HEADER_BUTTON_STYLE = ("QPushButton{background-image:url(%s);border:0px;}QPushButton:hover{background:url(%s);}QPushButton:pressed{background:url(%s);}")
@@ -151,13 +162,16 @@ AD_BUTTON_STYLE = ("QPushButton{background-image:url('%s');border:0px;}")
 # UBUNTU_SSO_SERVICE = 'http://login.ubuntukylin.com:8001/api/1.0'#'http://0.0.0.0:8000/api/1.0'
 UBUNTU_SSO_SERVICE = 'https://login.ubuntukylin.com/api/1.0'#'http://0.0.0.0:8000/api/1.0'
 SOFTWARE_CENTER_NAME_KEYRING = "Youker ID"
-SOFTWARE_CENTER_SSO_DESCRIPTION = '使用优客账号登录 Ubuntu Kylin 软件中心。'
+SOFTWARE_CENTER_SSO_DESCRIPTION = '使用优客账号登录银河软件中心。'
 datadir = "./utils/"
 PISTON_GENERIC_HELPER = "piston_generic_helper.py"
 
 
+
 class Signals:
     init_models_ready = pyqtSignal(str,str)
+
+    myinit_emit = pyqtSignal()
 #    chksoftwareover = pyqtSignal()
 #    getallpackagesover = pyqtSignal()
 #    countiover = pyqtSignal()
@@ -169,9 +183,9 @@ class Signals:
     #add
     task_reinstall = pyqtSignal()
     task_upgrade = pyqtSignal()
-    ads_ready = pyqtSignal(list,bool)
-    recommend_ready = pyqtSignal(list,bool)
-    ratingrank_ready = pyqtSignal(list,bool)
+    # ads_ready = pyqtSignal(list,bool)
+    recommend_ready = pyqtSignal(list,bool,bool)
+    # ratingrank_ready = pyqtSignal(list,bool)
     toprated_ready = pyqtSignal(list)
     rating_reviews_ready = pyqtSignal(list)
     app_reviews_ready = pyqtSignal(list)
@@ -179,9 +193,9 @@ class Signals:
     count_application_update = pyqtSignal()
     click_categoy = pyqtSignal(str,bool)
     click_item = pyqtSignal()
-    show_app_detail = pyqtSignal(Application)
+    show_app_detail = pyqtSignal(BaseInfo)
     install_debfile = pyqtSignal(Application)
-    install_app = pyqtSignal(Application)
+    install_app = pyqtSignal(BaseInfo)
     install_app_rcm = pyqtSignal(Application)
     remove_app = pyqtSignal(Application)
     upgrade_app = pyqtSignal(Application)
@@ -205,7 +219,7 @@ class Signals:
 #add
     recover_password_over = pyqtSignal(list)
     recover_password = pyqtSignal(str,str,str)
-    rset_password = pyqtSignal(str)
+    rset_password = pyqtSignal(str,str)
     rset_password_over = pyqtSignal(list)
     change_user_identity_over = pyqtSignal(list)
     change_identity = pyqtSignal()
@@ -225,9 +239,9 @@ class Signals:
     get_user_rating = pyqtSignal(int)
     unzip_img = pyqtSignal()
     mfb_click_run = pyqtSignal()
-    mfb_click_install = pyqtSignal(Application)
-    mfb_click_update = pyqtSignal(Application)
-    mfb_click_uninstall = pyqtSignal(Application)
+    mfb_click_install = pyqtSignal(BaseInfo)
+    mfb_click_update = pyqtSignal(BaseInfo)
+    mfb_click_uninstall = pyqtSignal(BaseInfo)
     get_card_status = pyqtSignal(str,int)
     trans_card_status = pyqtSignal(str,int)
     submit_translate_appinfo = pyqtSignal(str,str,str,str,str,str,str,str,str,str) #zx 2015.01.26
@@ -246,15 +260,28 @@ class Signals:
     ad_signal = pyqtSignal(int)
 
     #wb 2015.06.26
-    normalcard_progress_change = pyqtSignal(str,float,int)
+    normalcard_progress_change = pyqtSignal(str,float,str)
+    listitem_progress_change=pyqtSignal(str,float,str)
     normalcard_progress_finish = pyqtSignal(str)
     normalcard_progress_cancel = pyqtSignal(str)
     click_task = pyqtSignal(str)
 
+    # check and download kydroid apk source list
+    download_apk_source_over = pyqtSignal(bool)
+    apk_process = pyqtSignal(str, str, str, int, str)
+    kydroid_envrun_over = pyqtSignal(bool)
+    rcmdcard_kydroid_envrun = pyqtSignal()
+    normalcard_kydroid_envrun = pyqtSignal()
+
+    goto_login = pyqtSignal()
+
+    find_password= pyqtSignal()
+
 # application actions, this should sync with definition in apt_dbus_service
 class AppActions:
     INSTALLDEPS = "install_deps"
     INSTALLDEBFILE = "install_debfile"
+    DOWNLOADAPK = "download_apk"
     INSTALL = "install"
     REMOVE = "remove"
     UPGRADE = "upgrade"
