@@ -45,20 +45,21 @@ class WinCard(QWidget,Signals):
         self.messageBox = messageBox
 
         self.switchTimer = QTimer(self)
-        self.switchTimer.timeout.connect(self.slot_switch_animation_step)
+        # self.switchTimer.timeout.connect(self.slot_switch_animation_step)
 
         # add by kobe: delay show animation
         self.showDelay = False
         self.delayTimer = QTimer(self)
-        self.delayTimer.timeout.connect(self.slot_show_delay_animation)
+        # self.delayTimer.timeout.connect(self.slot_show_delay_animation)
 
         self.ui.btn.setFocusPolicy(Qt.NoFocus)
         self.ui.btnDetail.setFocusPolicy(Qt.NoFocus)
+        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-color:transparent;}")
 
-        self.ui.btnDetail.setCursor(Qt.PointingHandCursor)
+        # self.ui.btnDetail.setCursor(Qt.PointingHandCursor)
 
-        self.ui.description.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
-        self.ui.description.setReadOnly(True)
+        # self.ui.description.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
+        # self.ui.description.setReadOnly(True)
 
         # self.ui.baseWidget.setAutoFillBackground(True)
         # palette = QPalette()
@@ -66,36 +67,33 @@ class WinCard(QWidget,Signals):
         # self.ui.baseWidget.setPalette(palette)
 
         self.ui.baseWidget.setAutoFillBackground(True)
-        palette = QPalette()
-        img = QPixmap("res/wincard-base.png")
-        palette.setBrush(QPalette.Window, QBrush(img))
-        self.ui.baseWidget.setPalette(palette)
+        self.ui.baseWidget.setStyleSheet(".QWidget{border:1px solid #e5e5e5;background-color:#ffffff;}.QWidget:hover{border:1px solid #2d8ae1}")
 
         # self.ui.detailWidget.setAutoFillBackground(True)
         # palette = QPalette()
         # palette.setColor(QPalette.Background, QColor(245, 248, 250))
         # self.ui.detailWidget.setPalette(palette)
 
-        self.ui.detailWidget.setAutoFillBackground(True)
+        # self.ui.detailWidget.setAutoFillBackground(True)
         palette = QPalette()
         img = QPixmap("res/wincard-base.png")
         palette.setBrush(QPalette.Window, QBrush(img))
-        self.ui.detailWidget.setPalette(palette)
+        # self.ui.detailWidget.setPalette(palette)
 
         palette = QPalette()
         palette.setBrush(QPalette.Base, QBrush(QColor(255,0,0,0)))
-        self.ui.description.setPalette(palette)
+        # self.ui.description.setPalette(palette)
 
         img = QPixmap("res/arrowhead.png")
         self.ui.arronicon.setPixmap(img)
-
-        self.ui.winname.setStyleSheet("QLabel{font-size:13px;font-weight:bold;color:#666666;}")
-        self.ui.wintext.setStyleSheet("QLabel{font-size:13px;color:#888888;}")
-        self.ui.winbake.setStyleSheet("QLabel{font-size:13px;color:#888888;}")
-        self.ui.name.setStyleSheet("QLabel{font-size:13px;font-weight:bold;color:#666666;}")
-        self.ui.named.setStyleSheet("QLabel{font-size:13px;font-weight:bold;color:#666666;}")
-        self.ui.size.setStyleSheet("QLabel{font-size:13px;color:#888888;}")
-        self.ui.description.setStyleSheet("QTextEdit{border:0px;font-size:13px;color:#888888;}")
+        self.ui.arronicon.setStyleSheet("QLabel{background-color:transparent;}")
+        self.ui.winname.setStyleSheet("QLabel{font-size:13px;font-weight:bold;color:#666666;background-color:transparent;}")
+        # self.ui.wintext.setStyleSheet("QLabel{font-size:13px;color:#888888;}")
+        self.ui.winbake.setStyleSheet("QLabel{font-size:13px;color:#888888;background-color:transparent;}")
+        self.ui.name.setStyleSheet("QLabel{font-size:13px;font-weight:bold;color:#666666;background-color:transparent;}")
+        # self.ui.named.setStyleSheet("QLabel{font-size:13px;font-weight:bold;color:#666666;}")
+        self.ui.size.setStyleSheet("QLabel{font-size:13px;color:#888888;background-color:transparent;}")
+        # self.ui.description.setStyleSheet("QTextEdit{border:0px;font-size:13px;color:#888888;}")
 
         # win frame
         if(os.path.isfile(UBUNTUKYLIN_HTTP_WIN_RES_PATH + str(self.winstat.windows_app_name) + ".png")):
@@ -113,7 +111,7 @@ class WinCard(QWidget,Signals):
         #setLongTextToElideFormat(self.ui.winname, self.winstat.windows_app_name)
         #setLongTextToElideFormat(self.ui.wintext, self.winstat.display_name_windows)
         setLongTextToElideFormat(self.ui.winname, self.winstat.display_name_windows)
-        setLongTextToElideFormat(self.ui.wintext, self.winstat.windows_app_name)
+        # setLongTextToElideFormat(self.ui.wintext, self.winstat.windows_app_name)
         setLongTextToElideFormat(self.ui.winbake, self.winstat.category)
         # metrics = QFontMetrics(self.ui.winname.font())
         # elidedText = metrics.elidedText(self.winstat.windows_app_name, Qt.ElideRight, self.ui.winname.width())
@@ -123,10 +121,10 @@ class WinCard(QWidget,Signals):
         if self.app is None:
             if (self.winstat.app_name == 'wine-qq' or self.winstat.app_name == 'ppstream'):
                 iconpath = commontools.get_icon_path(self.winstat.app_name)
-                self.ui.icon.setStyleSheet("QLabel{background-image:url('" + iconpath + "')}")
+                self.ui.icon.setStyleSheet("QLabel{background-image:url('" + iconpath + "');background-color:transparent;}")
         else:
             iconpath = commontools.get_icon_path(self.app.name)
-            self.ui.icon.setStyleSheet("QLabel{background-image:url('" + iconpath + "')}")
+            self.ui.icon.setStyleSheet("QLabel{background-image:url('" + iconpath + "');background-color:transparent;}")
 
         # self.ui.baseWidget.setStyleSheet("QWidget{border:0px;}")
         # self.ui.homeline1.setStyleSheet("QLabel{background-color:#CCCCCC;}")
@@ -137,8 +135,8 @@ class WinCard(QWidget,Signals):
                 # self.ui.name.setText(self.winstat.app_name)
                 # self.ui.named.setText(self.winstat.app_name)
                 setLongTextToElideFormat(self.ui.name, self.winstat.app_name)
-                setLongTextToElideFormat(self.ui.named, self.winstat.app_name)
-                self.ui.description.setText(self.winstat.description)
+                # setLongTextToElideFormat(self.ui.named, self.winstat.app_name)
+                # self.ui.description.setText(self.winstat.description)
         else:
             # convert size
             installedsize = self.app.installedSize
@@ -151,65 +149,65 @@ class WinCard(QWidget,Signals):
             # add by kobe
             if self.app.displayname_cn != '' and self.app.displayname_cn is not None and self.app.displayname_cn != 'None':
                 setLongTextToElideFormat(self.ui.name, self.app.displayname_cn)
-                setLongTextToElideFormat(self.ui.named, self.app.displayname_cn)
+                # setLongTextToElideFormat(self.ui.named, self.app.displayname_cn)
             else:
                 setLongTextToElideFormat(self.ui.name, self.app.displayname)
-                setLongTextToElideFormat(self.ui.named, self.app.displayname)
-            if self.app.summary is not None and self.app.summary != 'None' and self.app.summary != '':
-                self.ui.description.setText(self.app.summary)
-            else:
-                self.ui.description.setText(self.app.orig_summary)
+                # setLongTextToElideFormat(self.ui.named, self.app.displayname)
+            # if self.app.summary is not None and self.app.summary != 'None' and self.app.summary != '':
+                # self.ui.description.setText(self.app.summary)
+            # else:
+            #     self.ui.description.setText(self.app.orig_summary)
 
         if self.app is None:
             if (self.winstat.app_name == 'wine-qq' or self.winstat.app_name == 'ppstream'):
                 self.ui.btn.setText("安装")
                 self.ui.btn.setEnabled(True)
-                self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-install-btn-3.png');}")
-                self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
+                self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}")
+                # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
             else:
                 self.ui.btn.setText("无效")
                 self.ui.btn.setEnabled(False)
-                self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-un-btn-3.png');}")
-                self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-un-border.png');}")
+                self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:0px;background-color:#ffffff;}")
+                # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-un-border.png');}")
         else:
             if app.status == PkgStates.INSTALLING:
                 self.ui.btn.setEnabled(False)
                 self.ui.btn.setText("正在安装")
-                self.ui.isInstalled.setVisible(False)
-                self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-install-btn-3.png');}")
-                self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
+                # self.ui.isInstalled.setVisible(False)
+                self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}")
+                # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
             elif app.status == PkgStates.REMOVING:
                 self.ui.btn.setEnabled(False)
                 self.ui.btn.setText("正在卸载")
-                self.ui.isInstalled.setVisible(False)
-                self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-un-btn-3.png');}")
-                self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
+                # self.ui.isInstalled.setVisible(False)
+                self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#e95421;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#e95421;}")
+                # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
             elif app.status == PkgStates.UPGRADING:
                 self.ui.btn.setEnabled(False)
                 self.ui.btn.setText("正在升级")
-                self.ui.isInstalled.setVisible(False)
-                self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-up-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-up-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-up-btn-3.png');}")
-                self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-up-border.png');}")
+                # self.ui.isInstalled.setVisible(False)
+                self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#07c30b;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#07c30b;}")
+                # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-up-border.png');}")
             else:
                 if(self.app.is_installed):
                     if(run.get_run_command(self.app.name) == ""):
                         self.app.status = PkgStates.NORUN
                         self.ui.btn.setText("已安装")
                         self.ui.btn.setEnabled(False)
-                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-un-btn-3.png');}")
-                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
+                        self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:0px;background-color:#ffffff;}")
+                        # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
                     else:
                         self.app.status = PkgStates.RUN
                         self.ui.btn.setText("启动")
                         self.ui.btn.setEnabled(True)
-                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-run-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-run-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-run-btn-3.png');}")
-                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-run-border.png');}")
+                        self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}")
+                        # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-run-border.png');}")
                 else:
                     self.app.status = PkgStates.INSTALL
                     self.ui.btn.setText("安装")
                     self.ui.btn.setEnabled(True)
-                    self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-install-btn-3.png');}")
-                    self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
+                    self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}")
+                    # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
 
         self.ui.btn.clicked.connect(self.slot_btn_click)
         self.ui.btnDetail.clicked.connect(self.slot_emit_detail)
@@ -219,54 +217,55 @@ class WinCard(QWidget,Signals):
         self.ui.setupUi(self)
         self.show()
 
-    def enterEvent(self, event):
-        self.delayTimer.start(300)
+    # def enterEvent(self, event):
+    #     if hasattr(self, "delayTimer"):
+    #         self.delayTimer.start(300)
         # self.switchDirection = 'down'
         # self.switch_animation()
 
-    def leaveEvent(self, event):
-        if self.delayTimer.isActive():
-            self.delayTimer.stop()
-        if self.showDelay:
-            self.showDelay = False
-            self.switchDirection = 'up'
-            self.switch_animation()
+    # def leaveEvent(self, event):
+    #     if self.delayTimer.isActive():
+    #         self.delayTimer.stop()
+    #     if self.showDelay:
+    #         self.showDelay = False
+    #         self.switchDirection = 'up'
+    #         self.switch_animation()
 
-    def slot_show_delay_animation(self):
-        self.delayTimer.stop()
-        self.switchDirection = 'down'
-        self.switch_animation()
-        self.showDelay = True
+    # def slot_show_delay_animation(self):
+    #     self.delayTimer.stop()
+    #     self.switchDirection = 'down'
+    #     self.switch_animation()
+    #     self.showDelay = True
 
-    def switch_animation(self):
-        if(self.switchDirection == 'down'):
-            self.py = -88
-            self.switchTimer.stop()
-            self.switchTimer.start(12)
-        else:
-            self.py = 0
-            self.switchTimer.stop()
-            self.switchTimer.start(12)
+    # def switch_animation(self):
+    #     if(self.switchDirection == 'down'):
+    #         self.py = -88
+    #         self.switchTimer.stop()
+    #         self.switchTimer.start(12)
+    #     else:
+    #         self.py = 0
+    #         self.switchTimer.stop()
+    #         self.switchTimer.start(12)
 
-    def slot_switch_animation_step(self):
-        if(self.switchDirection == 'down'):
-            if(self.py < 0):
-                self.py += 4
-                self.ui.detailWidget.move(0, self.py)
-                self.ui.baseWidget.move(0, self.py + 88)
-            else:
-                self.switchTimer.stop()
-                self.ui.detailWidget.move(0, 0)
-                self.ui.baseWidget.move(0, 0 + 88)
-        else:
-            if(self.py > -88):
-                self.py -= 4
-                self.ui.detailWidget.move(0, self.py)
-                self.ui.baseWidget.move(0, self.py + 88)
-            else:
-                self.switchTimer.stop()
-                self.ui.detailWidget.move(0, -88)
-                self.ui.baseWidget.move(0, 0)
+    # def slot_switch_animation_step(self):
+    #     if(self.switchDirection == 'down'):
+    #         if(self.py < 0):
+    #             self.py += 4
+    #             self.ui.detailWidget.move(0, self.py)
+    #             self.ui.baseWidget.move(0, self.py + 88)
+    #         else:
+    #             self.switchTimer.stop()
+    #             self.ui.detailWidget.move(0, 0)
+    #             self.ui.baseWidget.move(0, 0 + 88)
+    #     else:
+    #         if(self.py > -88):
+    #             self.py -= 4
+    #             self.ui.detailWidget.move(0, self.py)
+    #             self.ui.baseWidget.move(0, self.py + 88)
+    #         else:
+    #             self.switchTimer.stop()
+    #             self.ui.detailWidget.move(0, -88)
+    #             self.ui.baseWidget.move(0, 0)
 
     def slot_btn_click(self):
         if self.winstat.app_name == 'wine-qq':
@@ -302,20 +301,21 @@ class WinCard(QWidget,Signals):
                 if status == PkgStates.INSTALLING:
                     self.app.status = PkgStates.INSTALLING
                     self.ui.btn.setText("正在安装")
-                    self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-install-btn-3.png');}")
-                    self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
+                    self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}")
+                    # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
                 elif status == PkgStates.REMOVING:
                     self.app.status = PkgStates.REMOVING
                     self.ui.btn.setText("正在卸载")
-                    self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-un-btn-3.png');}")
-                    self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
+                    self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#e95421;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#e95421;}")
+                    # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
                 elif status == PkgStates.UPGRADING:
                     self.app.status = PkgStates.UPGRADING
                     self.ui.btn.setText("正在升级")
-                    self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-up-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-up-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-up-btn-3.png');}")
-                    self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-up-border.png');}")
+                    self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#07c30b;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#07c30b;}")
+                    # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-up-border.png');}")
         else:
-            print("self.app is None in wincard")
+            if (Globals.DEBUG_SWITCH):
+                print("self.app is None in wincard")
 
 
     def slot_emit_detail(self):
@@ -330,33 +330,33 @@ class WinCard(QWidget,Signals):
                         self.app.status = PkgStates.NORUN
                         self.ui.btn.setText("已安装")
                         self.ui.btn.setEnabled(False)
-                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-un-btn-3.png');}")
-                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
+                        self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:0px;background-color:#ffffff;}")
+                        # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
                     else:
                         self.app.status = PkgStates.RUN
                         self.ui.btn.setText("启动")
                         self.ui.btn.setEnabled(True)
-                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-run-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-run-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-run-btn-3.png');}")
-                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-run-border.png');}")
+                        self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}")
+                        # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-run-border.png');}")
                 elif action == AppActions.REMOVE:
                     self.app.status = PkgStates.INSTALL
                     self.ui.btn.setText("安装")
                     self.ui.btn.setEnabled(True)
-                    self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-install-btn-3.png');}")
-                    self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
+                    self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}")
+                    # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
                 elif action == AppActions.UPGRADE:
                     if(run.get_run_command(self.app.name) == ""):
                         self.app.status = PkgStates.NORUN
                         self.ui.btn.setText("已安装")
                         self.ui.btn.setEnabled(False)
-                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-un-btn-3.png');}")
-                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
+                        self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:0px;background-color:#ffffff;}")
+                        # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
                     else:
                         self.app.status = PkgStates.RUN
                         self.ui.btn.setText("启动")
                         self.ui.btn.setEnabled(True)
-                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-run-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-run-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-run-btn-3.png');}")
-                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-run-border.png');}")
+                        self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}")
+                        # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-run-border.png');}")
 
     def slot_work_cancel(self, pkgname, action):
         if self.app is not None:
@@ -365,21 +365,21 @@ class WinCard(QWidget,Signals):
                     self.app.status = PkgStates.INSTALL
                     self.ui.btn.setText("安装")
                     self.ui.btn.setEnabled(True)
-                    self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-install-btn-3.png');}")
-                    self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
+                    self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}")
+                    # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-install-border.png');}")
                 elif action in (AppActions.REMOVE, AppActions.UPGRADE):#can not appear on win page
                     if(run.get_run_command(self.app.name) == ""):
                         self.app.status = PkgStates.NORUN
                         self.ui.btn.setText("已安装")
                         self.ui.btn.setEnabled(False)
-                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-un-btn-3.png');}")
-                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
+                        self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:0px;background-color:#ffffff;}")
+                        # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-un-border.png');}")
                     else:
                         self.app.status = PkgStates.RUN
                         self.ui.btn.setText("启动")
                         self.ui.btn.setEnabled(True)
-                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/wincard-run-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/wincard-run-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/wincard-run-btn-3.png');}")
-                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-run-border.png');}")
+                        self.ui.btn.setStyleSheet("QPushButton{font-size:12px;color:#000000;border:1px solid #d5d5d5;background-color:#ffffff;}QPushButton:hover{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}QPushButton:pressed{font-size:12px;color:#ffffff;border:1px solid #d5d5d5;background-color:#2d8ae1;}")
+                        # self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/wincard-run-border.png');}")
                 # elif action == AppActions.UPGRADE:
                 #     self.app.status = PkgStates.UPDATE
                 #     self.ui.btn.setText("升级")
