@@ -25,6 +25,7 @@
 
 import os
 from models.enums import UBUNTUKYLIN_CACHE_ICON_PATH,UBUNTUKYLIN_RES_ICON_PATH
+from models.globals import Globals
 
 
 def get_icon_path(app_name):
@@ -47,4 +48,12 @@ def is_livecd_mode():
             return True
     else:
         f.close()
-        return False
\ No newline at end of file
+        return False
+
+if __name__ == "__main__":
+    from ctypes import cdll
+
+    cur = cdll.LoadLibrary('/home/huangsheng/aa.so')
+
+    if (Globals.DEBUG_SWITCH):
+        print(cur.test2(6))
\ No newline at end of file
